@@ -1,5 +1,8 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
 from admin_tools_stats.models import DashboardStatsCriteria, DashboardStats
+from common.app_label_renamer import AppLabelRenamer
+AppLabelRenamer(native_app_label=u'admin_tools_stats', app_label=_('Admin Tools Stats')).main()
 
 
 class DashboardStatsCriteriaAdmin(admin.ModelAdmin):
